<?php
/*
 * @package Avatars on Board_MessageIndex
 * @version 2.0.17
 * @Author: Pipke(AdemaStudios)
 * @copyright Copyright (C) 2020, Pipke
 * @All rights reserved. 
 * @This SMF modification is subject to the BSD 2-Clause License
 *
 * Redistribution and use in source and binary forms, with or without modification, are permitted provided that the following conditions are met:
 * 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions and the following disclaimer in the documentation and/or other materials provided with the distribution.
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT 
 * HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT 
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON 
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

if (!defined('SMF'))
	die('Hacking attempt...');

function abm_mod_admin(&$areas)
{	
	global $txt;
	
	loadLanguage('abm');	
	
	$areas['config']['areas']['modsettings']['subsections']['abm'] = array($txt['abm_name']);
}
	
function abm_mod_settings(&$sub_actions)
{	
	$sub_actions['abm'] = 'abm_sub_settings';	
}

function abm_sub_settings($return_config = false)
{
	global $context, $txt, $scripturl;
	
	// Style the preinput array text after the input box (int)
	$context['html_headers'] .= '
	<style type="text/css">
		#abm_avatar_size_board {
			float:left;
			margin-right: 2px;
			}
		#abm_avatar_size_message {
			float:left;
			margin-right: 2px;
			}
		#abm_avatar_size_global {
			float:left;
			margin-right: 2px;
			}
		#abm_width_message {
			float:left;
			margin-right: 2px;
			}
		#abm_width_board {
			float:left;
			margin-right: 2px;
			}
	</style>';
		
	// Admin layout
	$config_vars = array(
		array('title', 'abm_settings_title'),
		array('check', 'abm_boardindex'),
		array('int', 'abm_avatar_size_board', 'preinput' => 'px', 'size' => 2,),
		array('select', 'abm_width_board', 'subtext' => $txt['abm_width_sub'], array('0' => 0, '1' => $txt['abm_one'], '2' => 2, '3' => 3), 'preinput' => '%',),
		array('check', 'abm_avatar_layout_board', 'subtext' => $txt['abm_avatar_layout_sub'],),
		'',
		array('select', 'abm_messageindex', array('none' => $txt['abm_none'], 'first' => $txt['abm_first_poster'], 'last' => $txt['abm_last_poster'], 'both' => $txt['abm_both_poster'])),
		array('int', 'abm_avatar_size_message', 'preinput' => 'px', 'size' => 2,),
		array('select', 'abm_width_message', 'subtext' => $txt['abm_width_sub'], array('0' => 0, '1' => $txt['abm_one'], '2' => 2, '3' => 3), 'preinput' => '%',),
		array('check', 'abm_avatar_layout_message', 'subtext' => $txt['abm_avatar_layout_sub'],),
		'',
		array('int', 'abm_avatar_size_global', 'subtext' => $txt['abm_avatar_size_global_sub'], 'preinput' => 'px', 'size' => 2,),
		array('check', 'abm_avatar_layout_global', 'subtext' => $txt['abm_avatar_layout_sub'],),
		'',
		array('check', 'abm_messageindex_showtime', 'subtext' => $txt['abm_messageindex_showtime_sub']),
	);
	
	
	if ($return_config)		
		return $config_vars;

	$context['post_url'] = $scripturl . '?action=admin;area=modsettings;save;sa=abm';	
		
	if (empty($config_vars))
	{
		$context['settings_save_dont_show'] = false;
		$context['settings_message'] = '<div align="center">' . $txt['modification_no_misc_settings'] . '</div>';
		return prepareDBSettingContext($config_vars);	
	}
	
	// Save admin settings
	if (isset($_GET['save']))
	{		
		checkSession();	
		
		// Check pixel input for boardindex
		if (ctype_digit($_POST['abm_avatar_size_board']) && (strlen($_POST['abm_avatar_size_board']) <= 2 ))
			/*empty space*/;
		else
			fatal_lang_error('abm_error_size_board', false);
		
		// Check pixel input for messageindex
		if (ctype_digit($_POST['abm_avatar_size_message']) && (strlen($_POST['abm_avatar_size_message']) <= 2 ))
			/*empty space*/;
		else
			fatal_lang_error('abm_error_size_message', false);
		
		// Check pixel input for 'global' other
		if (ctype_digit($_POST['abm_avatar_size_global']) && (strlen($_POST['abm_avatar_size_global']) <= 2 ))
			/*empty space*/;
		else
			fatal_lang_error('abm_error_size_global', false);
					
		$context['save_vars'] = $config_vars;
		
		saveDBSettings($context['save_vars']);
		
		redirectexit('action=admin;area=modsettings;sa=abm');	
	}	

	prepareDBSettingContext($config_vars);
}

// Show credits
function abm_mod_setup(&$dummy)
{
	global $settings, $txt, $context, $smcFunc, $modSettings, $scripturl;
	
	if (isset($context['current_action']) && $context['current_action'] == 'credits')
		$context['copyrights']['mods'][] = '<a href="http://custom.simplemachines.org/mods/index.php?mod=4107">Avatars on Board/MessageIndex v2.0.17</a> | <a href="http://www.simplemachines.org/community/index.php?action=profile;u=314795" title="AdemaStudios">&copy 2020 by Pipke</a>';
	
	if (isset($context['current_action']) && !empty($context['current_action']))
	{
		if ($context['current_action'] == 'forum' ||  $context['current_action'] == 'unreadreplies' || $context['current_action'] == 'unread')
			/*empty space*/;
		else
			return;
	}
	
	// remove the 'abm_id={}' text
	$context['html_headers'] .= '
	<style type="text/css">
		.lastpost img {	
			color: rgba(0,0,0,0);
			font-size: 1px;
		}
		.subject img {	
			color: rgba(0,0,0,0);
			font-size: 1px;
		}
	</style>';
	
	$abm ='';
		
	// Find in messages the outprinted topics ¿maybe not found logic?
	if (isset($context['topics']) && !empty($context['topics']))
	{
		$abm_avatar_size = $modSettings['abm_avatar_size_message'] + 4;
		
		foreach ($context['topics'] as $abm_topics)
		{
			foreach(array($abm_topics['id']) as $context['abm_user_id'][]) {}
		}

		if (!empty($context['abm_user_id']))
		{				
			$request = $smcFunc['db_query']('','			
			SELECT 
				id_topic, id_member_started	, id_member_updated			
			FROM {db_prefix}topics				
			WHERE id_topic IN ({array_int:id})',		
			array(			
				'id' => $context['abm_user_id'],
				)							
			);	
			
			while ($row = $smcFunc['db_fetch_assoc']($request))	
			{	
				if ($modSettings['abm_messageindex_showtime']) //set time?
					if (isset($context['current_action']) && $context['current_action'] == 'unreadreplies' || $context['current_action'] == 'unread') //page
						$context['topics'][$row['id_topic']]['first_post']['member']['link'] = $context['topics'][$row['id_topic']]['first_post']['member']['link'].'</strong> '.$txt['on']. ' '. $context['topics'][$row['id_topic']]['first_post']['time'].'<strong><!---->';
					else
						$context['topics'][$row['id_topic']]['first_post']['member']['link'] = $context['topics'][$row['id_topic']]['first_post']['member']['link'].' '.$txt['on']. ' '. $context['topics'][$row['id_topic']]['first_post']['time'];
				
				if (($modSettings['abm_messageindex'] == 'first') || ($modSettings['abm_messageindex'] == 'both'))
				{
					// first post
					if ($row['id_member_started'])  //member
						$context['topics'][$row['id_topic']]['first_post']['link'] = '</span><div style="padding-left: '. $abm_avatar_size.'px; position: relative;"><a href="' . $scripturl . '?action=profile;u=' . $row['id_member_started'] . '"><img class="abm_avatar_message" alt="abm_id='.$row['id_member_started'].'" /></a>'.$context['topics'][$row['id_topic']]['first_post']['link'].'<span><!---->';	
					else //guest or deleted account
						$context['topics'][$row['id_topic']]['first_post']['link'] = '</span><div style="padding-left: '. $abm_avatar_size.'px; position: relative;"><img class="abm_avatar_message" alt="abm_id='.$row['id_member_started'].'" />'.$context['topics'][$row['id_topic']]['first_post']['link'].'<span><!---->';				
				
					// close div p small
					$context['topics'][$row['id_topic']]['pages'] = $context['topics'][$row['id_topic']]['pages'].'</small></p></div><p><small><!---->';				
				}
				// last post
				if (($modSettings['abm_messageindex'] == 'last') || ($modSettings['abm_messageindex'] == 'both'))
				{
					if ($row['id_member_updated']) //member
						$context['topics'][$row['id_topic']]['last_post']['href'] = '#"></a><div style="padding-left: '. $abm_avatar_size.'px; position: relative;"><a href="' . $scripturl . '?action=profile;u=' . $row['id_member_updated'] . '"><img class="abm_avatar_message" alt="abm_id='.$row['id_member_updated'].'" /></a><a href="'.$context['topics'][$row['id_topic']]['last_post']['href'];
					else //guest or deleted account
						$context['topics'][$row['id_topic']]['last_post']['href'] = '#"></a><div style="padding-left: '. $abm_avatar_size.'px; position: relative;"><img class="abm_avatar_message" alt="abm_id='.$row['id_member_updated'].'" /><a href="'.$context['topics'][$row['id_topic']]['last_post']['href'];
					
				// close div p 
				$context['topics'][$row['id_topic']]['last_post']['member']['link'] = $context['topics'][$row['id_topic']]['last_post']['member']['link'].'</div>';
				}
			}

			$smcFunc['db_free_result']($request);
		}
	}	
	
	if ($modSettings['abm_boardindex'])	
	{
		if (isset($context['current_action']) && !empty($context['current_action']))
		{
			if ($context['current_action'] != 'forum')
			return;
		}
	
		$abm_avatar_size = $modSettings['abm_avatar_size_board'] + 6;
	
		// Find in boards the outprinted childboards ¿maybe not found logic?
		if (isset($context['boards']) && !empty($context['boards']))
		{
			if (is_array($context['boards']))		
				foreach ($context['boards'] as $abm_boards)
				{
					if (is_array($abm_boards))			
						foreach(array($abm_boards['last_post']['topic']) as $context['abm_topic_ids'][]) {}
				}
	
			$abm_topic_ids = array_filter($context['abm_topic_ids']);
		
			if (!empty($abm_topic_ids))
			{							
				$request = $smcFunc['db_query']('','
				SELECT t.id_member_updated, t.id_topic, t.id_board, b.id_parent
				FROM {db_prefix}topics AS t
				LEFT JOIN {db_prefix}boards AS b ON (t.id_board = b.id_board)	
				WHERE id_topic IN ({array_int:ids})',			
				array(			
					'ids' => $abm_topic_ids,
					)							
				);		
				while ($row = $smcFunc['db_fetch_assoc']($request))	
				{																																																																										
					if ($row['id_member_updated']) //member   
					{				
						if (isset($context['boards'][$row['id_board']]))
							$context['boards'][$row['id_board']]['last_post']['member']['link'] = 'abm<!----></p><div style="padding-left: '. $abm_avatar_size.'px; position: relative;"><a href="' . $scripturl . '?action=profile;u=' . $row['id_member_updated'] . '"><img class="abm_avatar_board" alt="abm_id='.$row['id_member_updated'].'" /></a><b>'. $txt['last_post']. '</b>  '. $txt['by']. ' '.$context['boards'][$row['id_board']]['last_post']['member']['link'];					
						
						if (isset($context['boards'][$row['id_parent']]))
							$context['boards'][$row['id_parent']]['last_post']['member']['link'] = 'abm<!----></p><div style="padding-left: '. $abm_avatar_size.'px; position: relative;"><a href="' . $scripturl . '?action=profile;u=' . $row['id_member_updated'] . '"><img class="abm_avatar_board" alt="abm_id='.$row['id_member_updated'].'" /></a><b>'. $txt['last_post']. '</b>  '. $txt['by']. ' '.$context['boards'][$row['id_parent']]['last_post']['member']['link'];
					}				
					else //guest or deleted account
					{
						if (isset($context['boards'][$row['id_board']]))
							$context['boards'][$row['id_board']]['last_post']['member']['link'] = 'abm<!----></p><div style="padding-left: '. $abm_avatar_size.'px; position: relative;"><img class="abm_avatar_board" alt="abm_id='. $row['id_member_updated'] .'" /><b>'. $txt['last_post']. '</b>  '. $txt['by']. ' '.$context['boards'][$row['id_board']]['last_post']['member']['link'];
						
						if (isset($context['boards'][$row['id_parent']]))
							$context['boards'][$row['id_parent']]['last_post']['member']['link'] = 'abm<!----></p><div style="padding-left: '. $abm_avatar_size.'px; position: relative;"><img class="abm_avatar_board" alt="abm_id='. $row['id_member_updated'] .'" /><b>'. $txt['last_post']. '</b>  '. $txt['by']. ' '.$context['boards'][$row['id_parent']]['last_post']['member']['link'];
					}
				
					// close div p 
					if (isset($context['boards'][$row['id_board']]))
						$context['boards'][$row['id_board']]['last_post']['time'] = $context['boards'][$row['id_board']]['last_post']['time'].'</div><p><!---->';
				
					if (isset($context['boards'][$row['id_parent']]))
						$context['boards'][$row['id_parent']]['last_post']['time'] = $context['boards'][$row['id_parent']]['last_post']['time'].'</div><p><!---->';
				}					
			
				$smcFunc['db_free_result']($request);
			}				
		}

		// Find in categories the outprinted boards ¿maybe not found logic?
		if (isset($context['categories']) && !empty($context['categories']))
		{	
			if (is_array($context['categories']))
				foreach ($context['categories'] as $abm_id)	
				{
					if (is_array($abm_id))
						foreach($abm_id as $context['value'][]) {}
				}
	
			if (is_array($context['value']))	
				foreach ($context['value'] as $abm_ids)
				{
					if (is_array($abm_ids))
						foreach($abm_ids as $context['value'][]) {}
				}
	
			if (is_array($context['value']))		
				foreach ($context['value'] as $abm_boards)
				{
					if (is_array($abm_boards))
					{
						if (isset($abm_boards['id']))
							foreach(array($abm_boards['id']) as $context['abm_board_ids'][]) {}
						
						if (isset($abm_boards['last_post']['topic']))
							foreach(array($abm_boards['last_post']['topic']) as $context['abm_topic_ids'][]) {}
					}
				}
		
			$abm_topic_ids = array_filter($context['abm_topic_ids']);
			if (!empty($abm_topic_ids))
			{							
				$request = $smcFunc['db_query']('','
				SELECT id_member_updated, id_board
				FROM {db_prefix}topics 				
				WHERE id_topic IN ({array_int:ids})',			
					array(			
						'ids' => $abm_topic_ids,
						)							
				);		
				while ($row = $smcFunc['db_fetch_assoc']($request))	
				{																																																																										
					$context['abm_avatars_value'][$row['id_board']]['last_id_member'] = $row['id_member_updated'];
				}			
				$smcFunc['db_free_result']($request);
			
				$request = $smcFunc['db_query']('','
				SELECT id_cat, id_board, id_parent
				FROM {db_prefix}boards 				
				WHERE id_board IN ({array_int:id})',			
					array(			
						'id' => array_keys($context['abm_avatars_value']),
						)							
				);	
		
				while ($row = $smcFunc['db_fetch_assoc']($request))	
				{																																																																										
					$context['abm_avatars_value'][$row['id_board']]['parent'] = $row['id_parent'];
			
					if (!empty($row['id_parent']))
					{
						if ($context['abm_avatars_value'][$row['id_board']]['last_id_member']) //member
							if (isset($context['categories'][$row['id_cat']]['boards'][$row['id_parent']]))
								$context['categories'][$row['id_cat']]['boards'][$row['id_parent']]['last_post']['member']['link'] = 'abm<!----></p><div style="padding-left: '. $abm_avatar_size.'px; position: relative;"><a href="' . $scripturl . '?action=profile;u=' . $context['abm_avatars_value'][$row['id_board']]['last_id_member'] . '"><img class="abm_avatar_board" alt="abm_id='.$context['abm_avatars_value'][$row['id_board']]['last_id_member'].'" /></a><b>'. $txt['last_post']. '</b>  '. $txt['by']. ' '.$context['categories'][$row['id_cat']]['boards'][$row['id_parent']]['last_post']['member']['link'];
						else //guest or deleted account
							if (isset($context['categories'][$row['id_cat']]['boards'][$row['id_parent']]))
								$context['categories'][$row['id_cat']]['boards'][$row['id_parent']]['last_post']['member']['link'] = 'abm<!----></p><div style="padding-left: '. $abm_avatar_size.'px; position: relative;"><img class="abm_avatar_board" alt="abm_id='.$context['abm_avatars_value'][$row['id_board']]['last_id_member'].'" /><b>'. $txt['last_post']. '</b>  '. $txt['by']. ' '.$context['categories'][$row['id_cat']]['boards'][$row['id_parent']]['last_post']['member']['link'];
				
						// close div p 
						if (isset($context['categories'][$row['id_cat']]['boards'][$row['id_parent']]['last_post']['time']))
							$context['categories'][$row['id_cat']]['boards'][$row['id_parent']]['last_post']['time'] = $context['categories'][$row['id_cat']]['boards'][$row['id_parent']]['last_post']['time'].'</div><p><!---->';
					}
					else
					{
						if ($context['abm_avatars_value'][$row['id_board']]['last_id_member']) //member
							$context['categories'][$row['id_cat']]['boards'][$row['id_board']]['last_post']['member']['link'] = 'abm<!----></p><div style="padding-left: '. $abm_avatar_size.'px; position: relative;"><a href="' . $scripturl . '?action=profile;u=' . $context['abm_avatars_value'][$row['id_board']]['last_id_member'] . '"><img class="abm_avatar_board" alt="abm_id='.$context['abm_avatars_value'][$row['id_board']]['last_id_member'].'" /></a><b>'. $txt['last_post']. '</b>  '. $txt['by']. ' '.$context['categories'][$row['id_cat']]['boards'][$row['id_board']]['last_post']['member']['link'];
						else //guest or deleted account
							$context['categories'][$row['id_cat']]['boards'][$row['id_board']]['last_post']['member']['link'] = 'abm<!----></p><div style="padding-left: '. $abm_avatar_size.'px; position: relative;"><img class="abm_avatar_board" alt="abm_id='.$context['abm_avatars_value'][$row['id_board']]['last_id_member'].'" /><b>'. $txt['last_post']. '</b>  '. $txt['by']. ' '.$context['categories'][$row['id_cat']]['boards'][$row['id_board']]['last_post']['member']['link'];
				
						// close div p 
						$context['categories'][$row['id_cat']]['boards'][$row['id_board']]['last_post']['time'] = $context['categories'][$row['id_cat']]['boards'][$row['id_board']]['last_post']['time'].'</div><p><!---->';
					}
			
				}				
				$smcFunc['db_free_result']($request);
			}
		}			
	}		
}

function abm_mod_style($avatar)
{
	global $context, $modSettings, $settings, $txt;

	if (isset($_REQUEST['xml']))
		return $avatar;
	
	$find = array(	
	'~alt="abm_id=(\d+)"~',
	'~(alt="abm_id={$user_id}") ~',
	'~alt="abm_id=0"~',	// no user id
	'~<strong>'.$txt['last_post'].'</strong>~',
	'~'.$txt['by'].' abm~',
	'~class="abm_avatar_board"~',
	'~class="abm_avatar_message"~',
	'~width="22%">~',  // column message last
	'~width="14%">~',  // column message stats
	'~class="lastpost"~',  // column board last
	'~class="stats windowbg"~',	// column board stats	
	'~class="avatar"~',
	'~<p>abm<!----></p>~',
	);
	
	// Round
	$border_board = $modSettings['abm_avatar_layout_board']  ? '50' : '0';
	$border_message = $modSettings['abm_avatar_layout_message']  ? '50' : '0';
	// Board
	$abm_avatar_size_board = $modSettings['abm_avatar_size_board'] /2;
	$abm_width_board = 15 - $modSettings['abm_width_board'];
	$modSettings['abm_width_board'] = 24 + $modSettings['abm_width_board'];
	// Message
	$abm_avatar_size_message = $modSettings['abm_avatar_size_message'] /2;
	$abm_width_message = 14 - $modSettings['abm_width_message'];
	$modSettings['abm_width_message'] = 22 + $modSettings['abm_width_message'];
	
	// Identifier transform to avatar
	$user_ids = preg_match_all($find[0], $avatar, $matches) ? array_unique($matches[1]) : array();
	$avatar = preg_replace($find[2], ' src="'.$settings['images_url']. '/abm_avatar.gif"', $avatar); 
	// Text strings removal
	$avatar = preg_replace($find[3], '', $avatar);
	$avatar = preg_replace($find[4], '', $avatar);
	// Avatar styling
	$avatar = preg_replace($find[5], 'style="width: '. $modSettings['abm_avatar_size_board'] .'px; height: '. $modSettings['abm_avatar_size_board'] .'px; left: 0; position: absolute; top: 50%; margin-top: -'. $abm_avatar_size_board .'px; padding: 0px; border-radius: '. $border_board .'%;"', $avatar);
	$avatar = preg_replace($find[6], 'style="width: '. $modSettings['abm_avatar_size_message'] .'px; height: '. $modSettings['abm_avatar_size_message'] .'px; left: 0; position: absolute; top: 50%; margin-top: -'. $abm_avatar_size_message .'px; padding: 0px; border-radius: '. $border_message .'%;"', $avatar);
	// Width col message	
	$avatar = preg_replace($find[7], 'width="'. $modSettings['abm_width_message'] .'%">', $avatar);  
	$avatar = preg_replace($find[8], 'width="'. $abm_width_message .'%">', $avatar); 
	// Width col board
	$avatar = preg_replace($find[9], 'class="lastpost" style="width: '. $modSettings['abm_width_board'] .'%;"', $avatar);
	$avatar = preg_replace($find[10], 'class="stats windowbg" style="width: '. $abm_width_board .'%;"', $avatar);
	$avatar = preg_replace($find[12], '', $avatar);
	// Global styling
	if ($modSettings['abm_avatar_layout_global'])
		$avatar = preg_replace($find[11], 'style="width: '. $modSettings['abm_avatar_size_global'] .'px; height: '. $modSettings['abm_avatar_size_global'] .'px; border-radius: 50%;"', $avatar);
	

	if (($user_avatars = abm_loadAvatars($user_ids)) !== false)
		foreach ($user_avatars as $user_id => $user_avatar)
			$avatar = preg_replace(str_replace('{$user_id}', $user_id, $find[1]), '$1' . $user_avatar, $avatar);
	
	return $avatar;
}

function abm_loadAvatars($user_ids = array())
{
	global $smcFunc, $user_profile, $scripturl, $modSettings, $settings;
	//global $boardurl, $image_proxy_enabled, $image_proxy_secret;
	
	if (empty($user_ids))
		return false;

	$user_ids = is_array($user_ids) ? $user_ids : array($user_ids);
	
	$request = $smcFunc['db_query']('','
		SELECT mem.id_member, 
		IFNULL(av.id_attach, 0) AS id_attach, av.filename, av.attachment_type, mem.avatar AS avatar_poster
		FROM {db_prefix}members AS mem
		 LEFT JOIN {db_prefix}members AS memid ON (memid.id_member = mem.id_member)
		 LEFT JOIN {db_prefix}attachments AS av ON (av.id_member = mem.id_member)
		WHERE mem.id_member IN ({array_int:user_ids})',
		array(
			'user_ids'	=> $user_ids,
		)
	);
	$user_avatars = array();
	while ($row = $smcFunc['db_fetch_assoc']($request))
	{		
		$avatar = $row['avatar_poster'] == '' ? ($row['id_attach'] > 0 ? (empty($row['attachment_type']) ? $scripturl . '?action=dlattach;attach=' . $row['id_attach'] . ';type=avatar' : $modSettings['custom_avatar_url'] . '/' . $row['filename']) : '') : (stristr($row['avatar_poster'], 'http') ? $row['avatar_poster'] : $modSettings['avatar_url'] . '/' . $row['avatar_poster']);
				
		## Uncomment below lines if you want to check for attachment avatars that are deleted from server, note that this will make the pages load longer! ##
		//if( strpos($avatar, 'type=avatar') !== false)
		//{
		//	if (!@getimagesize($avatar))
		//		$avatar = $settings['images_url']. '/abm_avatar.gif';
		//}
		
		// Take care of proxying avatar if required
		if (substr($avatar, 0, 7) == 'http://' || substr($avatar, 0, 8) == 'https://')
			$avatar = get_proxied_url($avatar);
		
		if (empty($avatar))
			$avatar = $settings['images_url']. '/abm_avatar.gif';
		
		$user_avatars[$row['id_member']] = ' src="'.$avatar.'"';
		
		unset($row['attachment_type'], $row['id_attach'], $row['filename'], $row['avatar_poster']);		
	}
	$smcFunc['db_free_result']($request);

	return $user_avatars;
}
?>
